@@ -1,5 +1,5 @@
 /* 
- * Copyright (c) Tony Bybell 2004-2010.
+ * Copyright (c) Tony Bybell 2004-2011.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -27,6 +27,7 @@
 #include "debug.h"
 #include "busy.h"
 
+
 /* 
  * select appropriate entry points based on if aet2
  * support is available
@@ -51,6 +52,7 @@ exit(255);
 
 #else
 
+
 /*
  * iter mask manipulation util functions
  */
@@ -68,10 +70,8 @@ return(0);
 }
 
 
-int aet2_rd_set_fac_process_mask(unsigned int facidx)
+void aet2_rd_set_fac_process_mask(unsigned int facidx)
 {
-int rc=1;
-
 if(facidx<GLOBALS->numfacs)
 	{
 	int idx = facidx/8;
@@ -79,15 +79,11 @@ if(facidx<GLOBALS->numfacs)
 
 	GLOBALS->ae2_process_mask[idx] |= (1<<bitpos);
 	}
-
-return(rc);
 }
 
 
-int aet2_rd_clr_fac_process_mask(unsigned int facidx)
+void aet2_rd_clr_fac_process_mask(unsigned int facidx)
 {
-int rc=1;
-
 if(facidx<GLOBALS->numfacs)
 	{
 	int idx = facidx/8;
@@ -95,8 +91,6 @@ if(facidx<GLOBALS->numfacs)
 
 	GLOBALS->ae2_process_mask[idx] &= (~(1<<bitpos));
 	}
-
-return(rc);
 }
 
 
@@ -163,10 +157,14 @@ TimeType ae2_main(char *fname, char *skip_start, char *skip_end, char *indirect_
 int i;
 int match_idx;
 struct Node *n;
-struct symbol *s, *prevsymroot=NULL, *prevsym=NULL;
+struct symbol *s;
 FILE *ind_h = NULL;
 TimeType first_cycle, last_cycle, total_cycles;
 char *info_fname = NULL;
+int total_rows = 0;
+int mono_row_offset = 0;
+struct Node *monolithic_node = NULL;
+struct symbol *monolithic_sym = NULL;
 
 ae2_initialize(error_fn, msg_fn, alloc_fn, free_fn);
 
@@ -209,8 +207,8 @@ if ( (!(GLOBALS->ae2_info_f=fopen(info_fname, "rb"))) || (!(GLOBALS->ae2_info =
 	uint64_t en_2 = ae2_read_end_cycle(GLOBALS->ae2_info);
 
 	FACREF time_fr, prec_fr;
-        ulong time_rc = ae2_read_find_symbol(GLOBALS->ae2_info, AET2_TIMEFAC, &time_fr);
-        ulong prec_rc = ae2_read_find_symbol(GLOBALS->ae2_info, AET2_PRECFAC, &prec_fr);
+        unsigned long time_rc = ae2_read_find_symbol(GLOBALS->ae2_info, AET2_TIMEFAC, &time_fr);
+        unsigned long prec_rc = ae2_read_find_symbol(GLOBALS->ae2_info, AET2_PRECFAC, &prec_fr);
 
 	if((m1 == m2) && (st_1 == st_2) && (en_1 == en_2) && (time_rc) && (prec_rc) & (time_fr.length == 64))
 		{
@@ -266,6 +264,9 @@ sym_hash_initialize(GLOBALS);
 GLOBALS->ae2_num_sections=ae2_read_num_sections(GLOBALS->ae2);
 GLOBALS->numfacs=ae2_read_num_symbols(GLOBALS->ae2);
 GLOBALS->ae2_process_mask = calloc_2(1, GLOBALS->numfacs/8+1);
+#ifdef AE2_EXPERIMENTAL_TO_INTEGRATE
+GLOBALS->ae2_invert_idx = calloc_2(GLOBALS->numfacs + 1, sizeof(struct symbol *));
+#endif
 
 if(indirect_fname)
 	{
@@ -336,7 +337,7 @@ if(indirect_fname)
 	
 			for(i=0;i<GLOBALS->numfacs;i++)
 				{
-			        char buf[65537];
+			        char buf[AE2_MAX_NAME_LENGTH+1];
 			        int idx = i+1;
 			
 			        ae2_read_symbol_name(GLOBALS->ae2, idx, buf);
@@ -378,6 +379,45 @@ if(indirect_fname)
 			}
 		}
 	}
+	else
+	{
+	if(1)
+		{
+		int early_out = 0;
+		fprintf(stderr, AET2_RDLOAD"Filtering BugSpray facilities...\n");
+		GLOBALS->ae2_regex_matches = 0;
+		for(i=0;i<GLOBALS->numfacs;i++)
+		        {
+		        char buf[AE2_MAX_NAME_LENGTH+1];
+		        int idx = i+1;
+	
+			ae2_read_symbol_name(GLOBALS->ae2, idx, buf);
+	
+			if(buf[0] == 'B')
+				{
+				if(buf[1] == 'S')
+					{
+					if(buf[2] == '%')
+						{
+						early_out = 1;
+						continue;
+						}
+					}
+				}
+	
+			if(early_out) break;
+	
+			aet2_rd_set_fac_process_mask(i);
+			GLOBALS->ae2_regex_matches++;
+			}
+	
+		for(;i<GLOBALS->numfacs;i++)
+		        {
+			aet2_rd_set_fac_process_mask(i);
+			GLOBALS->ae2_regex_matches++;
+			}
+		}
+	}
 
 if(!GLOBALS->ae2_regex_matches)
 	{
@@ -393,15 +433,13 @@ if(!GLOBALS->ae2_regex_matches)
 match_idx = 0;
 for(i=0;i<GLOBALS->numfacs;i++)
 	{
-        char buf[65537];
         int idx = i+1;
 
 	if((GLOBALS->ae2_regex_matches)&&(!aet2_rd_get_fac_process_mask(i))) continue;
-
-        ae2_read_symbol_name(GLOBALS->ae2, idx, buf);
  
         GLOBALS->ae2_fr[match_idx].facname = NULL;
         GLOBALS->ae2_fr[match_idx].row = ae2_read_symbol_rows(GLOBALS->ae2, idx);
+	total_rows += (GLOBALS->ae2_fr[match_idx].row > 0) ? GLOBALS->ae2_fr[match_idx].row : 1;
 	if(GLOBALS->ae2_fr[match_idx].row == 1) GLOBALS->ae2_fr[match_idx].row = 0;
         GLOBALS->ae2_fr[match_idx].length = ae2_read_symbol_length(GLOBALS->ae2, idx);
         GLOBALS->ae2_fr[match_idx].s = idx;
@@ -411,6 +449,9 @@ for(i=0;i<GLOBALS->numfacs;i++)
 	match_idx++;
 	}
 
+monolithic_node = calloc_2(total_rows, sizeof(struct Node));
+monolithic_sym = calloc_2(match_idx, sizeof(struct symbol));
+
 fprintf(stderr, AET2_RDLOAD"Finished building %d facs.\n", match_idx);
 /* SPLASH */                            splash_sync(1, 5);
 
@@ -429,21 +470,20 @@ match_idx = 0;
 for(i=0;i<GLOBALS->numfacs;i++)
         {
 	char *str;	
-        char buf[65537];
+        char buf[AE2_MAX_NAME_LENGTH+1];
         int idx = i+1;
-	unsigned long len;
+	unsigned long len, clen;
 	int row_iter, mx_row, mx_row_adjusted;
 
 	if((GLOBALS->ae2_regex_matches)&&(!aet2_rd_get_fac_process_mask(i))) continue;
 
-	len = ae2_read_symbol_name(GLOBALS->ae2, idx, buf);	/* previously had -1, but it no longer returns the zero byte counted */
-	buf[len] = 0;					/* only being defensive here, not really necessary */
+	len = ae2_read_symbol_name(GLOBALS->ae2, idx, buf);
 
 	if(GLOBALS->ae2_fr[match_idx].length>1)
 		{
 		int len2;
 		FACREF info_fr;
-		ulong find_rc;
+		unsigned long find_rc;
 
 		if((GLOBALS->ae2_info)&&((find_rc = ae2_read_find_symbol(GLOBALS->ae2_info, buf, &info_fr)))&&(info_fr.length == 32))
 			{
@@ -466,7 +506,8 @@ for(i=0;i<GLOBALS->numfacs;i++)
 			}
 
 
-		str=malloc_2(len + len2 + 1);
+		str=malloc_2(clen = (len + len2 + 1));
+		if(clen > GLOBALS->longestname) GLOBALS->longestname = clen;
 		if(!GLOBALS->alt_hier_delimeter)
 			{
 			strcpy(str, buf);
@@ -475,12 +516,13 @@ for(i=0;i<GLOBALS->numfacs;i++)
 			{
 			strcpy_vcdalt(str, buf, GLOBALS->alt_hier_delimeter);
 			}
-	        s=symadd_name_exists(str,0);
-		prevsymroot = prevsym = NULL;
+		s = &monolithic_sym[match_idx];
+	        symadd_name_exists_sym_exists(s, str,0);
 		}
 		else
 		{
-		str=malloc_2(len+1);
+		str=malloc_2(clen = (len+1));
+		if(clen > GLOBALS->longestname) GLOBALS->longestname = clen;
 		if(!GLOBALS->alt_hier_delimeter)
 			{
 			strcpy(str, buf);
@@ -489,26 +531,19 @@ for(i=0;i<GLOBALS->numfacs;i++)
 			{
 			strcpy_vcdalt(str, buf, GLOBALS->alt_hier_delimeter);
 			}
-	        s=symadd_name_exists(str,0);
-		prevsymroot = prevsym = NULL;
+		s = &monolithic_sym[match_idx];
+	        symadd_name_exists_sym_exists(s, str,0);
 		}
 		
-	if(!GLOBALS->firstnode)
-	        {
-	        GLOBALS->firstnode=
-	        GLOBALS->curnode=calloc_2(1, sizeof(struct symchain));
-	        }   
-	        else                                     
-	        {
-	        GLOBALS->curnode->next=calloc_2(1, sizeof(struct symchain));
-	        GLOBALS->curnode=GLOBALS->curnode->next;
-	        }
-	GLOBALS->curnode->symbol=s;
+#ifdef AE2_EXPERIMENTAL_TO_INTEGRATE
+        GLOBALS->ae2_invert_idx[idx] = s;
+#endif
 
         mx_row = (GLOBALS->ae2_fr[match_idx].row < 1) ? 1 : GLOBALS->ae2_fr[match_idx].row;
 	mx_row_adjusted = (mx_row < 2) ? 0 : mx_row;
-        n=(struct Node *)calloc_2(mx_row,sizeof(struct Node));
+        n=&monolithic_node[mono_row_offset];
 	s->n = n;
+	mono_row_offset += mx_row;
 
 	for(row_iter = 0; row_iter < mx_row; row_iter++)
 		{
@@ -545,27 +580,21 @@ GLOBALS->facs=(struct symbol **)malloc_2(GLOBALS->numfacs*sizeof(struct symbol *
 
 if(GLOBALS->fast_tree_sort)
 	{
-	GLOBALS->curnode=GLOBALS->firstnode;
 	for(i=0;i<GLOBALS->numfacs;i++)
 		{
-		int len;
-		struct symchain *sc;
-		GLOBALS->facs[i]=GLOBALS->curnode->symbol;
-	        if((len=strlen(GLOBALS->facs[i]->name))>GLOBALS->longestname) GLOBALS->longestname=len;
-		sc = GLOBALS->curnode;
-		GLOBALS->curnode=GLOBALS->curnode->next;
-		free_2(sc);
+		GLOBALS->facs[i]=&monolithic_sym[i];
 		}
-	GLOBALS->firstnode=GLOBALS->curnode=NULL;
 
 /* SPLASH */                            splash_sync(3, 5);
 	fprintf(stderr, AET2_RDLOAD"Building facility hierarchy tree.\n");
 
 	init_tree();		
+
 	for(i=0;i<GLOBALS->numfacs;i++)	
 		{
 		build_tree_from_name(GLOBALS->facs[i]->name, i);
 		}
+
 /* SPLASH */                            splash_sync(4, 5);
 	treegraft(&GLOBALS->treeroot);
 
@@ -578,21 +607,13 @@ if(GLOBALS->fast_tree_sort)
 	}
 	else
 	{
-	GLOBALS->curnode=GLOBALS->firstnode;
 	for(i=0;i<GLOBALS->numfacs;i++)
 		{
-		char *subst;
 #ifdef WAVE_HIERFIX
+		char *subst;
 		char ch;	
 #endif
-		int len;
-		struct symchain *sc;
-
-		GLOBALS->facs[i]=GLOBALS->curnode->symbol;
-	        if((len=strlen(subst=GLOBALS->facs[i]->name))>GLOBALS->longestname) GLOBALS->longestname=len;
-		sc = GLOBALS->curnode;
-		GLOBALS->curnode=GLOBALS->curnode->next;
-		free_2(sc);
+		GLOBALS->facs[i]=&monolithic_sym[i];
 #ifdef WAVE_HIERFIX
 		while((ch=(*subst)))
 			{	
@@ -601,7 +622,6 @@ if(GLOBALS->fast_tree_sort)
 			}
 #endif
 		}
-	GLOBALS->firstnode=GLOBALS->curnode=NULL;
 	
 /* SPLASH */                            splash_sync(3, 5);
 	fprintf(stderr, AET2_RDLOAD"Sorting facilities at hierarchy boundaries.\n");
@@ -774,7 +794,7 @@ unsigned int i, j, r;
 uint64_t cyc, ecyc, step_cyc;
 struct ae2_ncycle_autosort *deadlist=NULL;
 struct ae2_ncycle_autosort *autofacs=NULL;
-char buf[65537];
+char buf[AE2_MAXFACLEN+1];
 
 
 GLOBALS->ae2_msg_suppress = 1;
@@ -831,7 +851,7 @@ for(j=0;j<GLOBALS->ae2_num_sections;j++)
 				}
 				else
 				{
-				ulong sf = ae2_read_symbol_sparse_flag(GLOBALS->ae2, GLOBALS->ae2_fr[i].s);
+				unsigned long sf = ae2_read_symbol_sparse_flag(GLOBALS->ae2, GLOBALS->ae2_fr[i].s);
 				if(sf)
 					{
 					int rows = ae2_read_num_sparse_rows(GLOBALS->ae2, GLOBALS->ae2_fr[i].s, cyc);
@@ -898,7 +918,7 @@ for(j=0;j<GLOBALS->ae2_num_sections;j++)
 			}
 			else
 			{
-			ulong sf = ae2_read_symbol_sparse_flag(GLOBALS->ae2, GLOBALS->ae2_fr[i].s);
+			unsigned long sf = ae2_read_symbol_sparse_flag(GLOBALS->ae2, GLOBALS->ae2_fr[i].s);
 			if(sf)
 				{
 				int rows = ae2_read_num_sparse_rows(GLOBALS->ae2, GLOBALS->ae2_fr[i].s, cyc);
@@ -998,7 +1018,7 @@ for(j=0;j<GLOBALS->ae2_num_sections;j++)
 					}
 					else
 					{
-					ulong sf = ae2_read_symbol_sparse_flag(GLOBALS->ae2, GLOBALS->ae2_fr[i].s);
+					unsigned long sf = ae2_read_symbol_sparse_flag(GLOBALS->ae2, GLOBALS->ae2_fr[i].s);
 					if(sf)
 						{
 						int rows = ae2_read_num_sparse_rows(GLOBALS->ae2, GLOBALS->ae2_fr[i].s, step_cyc);
@@ -1376,6 +1396,66 @@ for(txidx=0;txidx<GLOBALS->numfacs;txidx++)
 	}
 }
 
+
+#ifdef AE2_EXPERIMENTAL_TO_INTEGRATE
+struct symbol *symfind_ae2(char *s, unsigned int *rows_return)
+{
+char *s2 = s;
+char buf[AE2_MAX_NAME_LENGTH+1];
+char *d = buf;
+char *last_brack = NULL;
+char *last_brace = NULL;
+struct facref fr;
+ulong u;
+
+if ((!s)||(!s[0])) return(NULL);
+if(rows_return)
+        {
+        *rows_return = 0;
+        }
+
+while(*s2)
+	{
+	*d = *s2;
+
+	if(*s2 == '[')
+		{
+		last_brack = d;
+		}
+	else if(*s2 == '{')
+		{
+		last_brace = d;
+		}
+
+	s2++;
+	d++;
+	}
+*d = 0;
+
+d = buf;
+if(last_brack)
+	{
+	*last_brack = 0;
+	}
+
+if(rows_return)
+	{
+	if(last_brace)
+		{
+		*rows_return = atoi(last_brace+1);
+		}
+		else
+		{
+		*rows_return = 0;
+		}
+	}
+
+u = ae2_read_find_symbol(GLOBALS->ae2, d, &fr);
+
+return(GLOBALS->ae2_invert_idx[u]);
+}
+#endif
+
 #endif
 /* ...of AET2_IS_PRESENT */
 
