@@ -1,5 +1,5 @@
 /* 
- * Copyright (c) Tony Bybell 2003-2010.
+ * Copyright (c) Tony Bybell 2003-2011.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -65,9 +65,9 @@ node_block=(struct Node *)calloc_2(GLOBALS->numfacs,sizeof(struct Node));
 
 for(i=0;i<GLOBALS->numfacs;i++)
 	{
-	GLOBALS->mvlfacs_lx2_c_1[i].array_height=lxt2_rd_get_fac_rows(GLOBALS->lx2_lx2_c_1, i);
-	GLOBALS->mvlfacs_lx2_c_1[i].msb=lxt2_rd_get_fac_msb(GLOBALS->lx2_lx2_c_1, i);
-	GLOBALS->mvlfacs_lx2_c_1[i].lsb=lxt2_rd_get_fac_lsb(GLOBALS->lx2_lx2_c_1, i);
+	GLOBALS->mvlfacs_lx2_c_1[i].node_alias=lxt2_rd_get_fac_rows(GLOBALS->lx2_lx2_c_1, i);
+	node_block[i].msi=lxt2_rd_get_fac_msb(GLOBALS->lx2_lx2_c_1, i);
+	node_block[i].lsi=lxt2_rd_get_fac_lsb(GLOBALS->lx2_lx2_c_1, i);
 	GLOBALS->mvlfacs_lx2_c_1[i].flags=lxt2_rd_get_fac_flags(GLOBALS->lx2_lx2_c_1, i);
 	GLOBALS->mvlfacs_lx2_c_1[i].len=lxt2_rd_get_fac_len(GLOBALS->lx2_lx2_c_1, i);
 	}
@@ -89,24 +89,9 @@ if(!GLOBALS->hier_was_explicitly_set)    /* set default hierarchy split char */
 if(GLOBALS->numfacs)
 	{
 	char *fnam = lxt2_rd_get_facname(GLOBALS->lx2_lx2_c_1, 0);
-        char *pnt = NULL;
-        int was_packed = 0;
-
-        if(GLOBALS->do_hier_compress)
-                {
-                pnt = hier_compress(fnam, HIERPACK_ADD, &was_packed);
-                }
-
-        if(was_packed)
-                {
-                f_name[0] = pnt;
-                }
-                else
-                {
-		int flen = strlen(fnam);
-		f_name[0]=malloc_2(flen+1);
-		strcpy(f_name[0], fnam);
-                }
+	int flen = strlen(fnam);
+	f_name[0]=malloc_2(flen+1);
+	strcpy(f_name[0], fnam);
 	}
 
 for(i=0;i<GLOBALS->numfacs;i++)
@@ -118,24 +103,9 @@ for(i=0;i<GLOBALS->numfacs;i++)
 	if(i!=(GLOBALS->numfacs-1))
 		{
 		char *fnam = lxt2_rd_get_facname(GLOBALS->lx2_lx2_c_1, i+1);
-	        char *pnt = NULL;
-	        int was_packed = 0;
-
-	        if(GLOBALS->do_hier_compress)
-	                {
-	                pnt = hier_compress(fnam, HIERPACK_ADD, &was_packed);
-	                }
-
-	        if(was_packed)
-	                {
-			f_name[(i+1)&F_NAME_MODULUS] = pnt;
-			}
-			else
-			{
-			int flen = strlen(fnam);
-			f_name[(i+1)&F_NAME_MODULUS]=malloc_2(flen+1);
-			strcpy(f_name[(i+1)&F_NAME_MODULUS], fnam);
-			}
+		int flen = strlen(fnam);
+		f_name[(i+1)&F_NAME_MODULUS]=malloc_2(flen+1);
+		strcpy(f_name[(i+1)&F_NAME_MODULUS], fnam);
 		}
 
 	if(i>1)
@@ -146,12 +116,12 @@ for(i=0;i<GLOBALS->numfacs;i++)
 
 	if(GLOBALS->mvlfacs_lx2_c_1[i].flags&LXT2_RD_SYM_F_ALIAS)
 		{
-		int alias = GLOBALS->mvlfacs_lx2_c_1[i].array_height;
+		int alias = GLOBALS->mvlfacs_lx2_c_1[i].node_alias;
 		f=GLOBALS->mvlfacs_lx2_c_1+alias;
 
 		while(f->flags&LXT2_RD_SYM_F_ALIAS)
 			{
-			f=GLOBALS->mvlfacs_lx2_c_1+f->array_height;
+			f=GLOBALS->mvlfacs_lx2_c_1+f->node_alias;
 			}
 
 		numalias++;
@@ -163,7 +133,7 @@ for(i=0;i<GLOBALS->numfacs;i++)
 
 	if((f->len>1)&& (!(f->flags&(LXT2_RD_SYM_F_INTEGER|LXT2_RD_SYM_F_DOUBLE|LXT2_RD_SYM_F_STRING))) )
 		{
-		int len = sprintf(buf, "%s[%d:%d]", f_name[(i)&F_NAME_MODULUS],GLOBALS->mvlfacs_lx2_c_1[i].msb, GLOBALS->mvlfacs_lx2_c_1[i].lsb);
+		int len = sprintf(buf, "%s[%d:%d]", f_name[(i)&F_NAME_MODULUS],node_block[i].msi, node_block[i].lsi);
 		str=malloc_2(len+1);
 		if(!GLOBALS->alt_hier_delimeter)
 			{
@@ -177,58 +147,58 @@ for(i=0;i<GLOBALS->numfacs;i++)
                 symadd_name_exists_sym_exists(s,str,0);
 		prevsymroot = prevsym = NULL;
 		}
-	else if ( 
-			((f->len==1)&&(!(f->flags&(LXT2_RD_SYM_F_INTEGER|LXT2_RD_SYM_F_DOUBLE|LXT2_RD_SYM_F_STRING)))&&
-			((i!=GLOBALS->numfacs-1)&&(!strcmp(f_name[(i)&F_NAME_MODULUS], f_name[(i+1)&F_NAME_MODULUS]))))
-			||
-			(((i!=0)&&(!strcmp(f_name[(i)&F_NAME_MODULUS], f_name[(i-1)&F_NAME_MODULUS]))) &&
-			(GLOBALS->mvlfacs_lx2_c_1[i].msb!=-1)&&(GLOBALS->mvlfacs_lx2_c_1[i].lsb!=-1))
-		)
-		{
-		int len = sprintf(buf, "%s[%d]", f_name[(i)&F_NAME_MODULUS],GLOBALS->mvlfacs_lx2_c_1[i].msb);
-		str=malloc_2(len+1);
-		if(!GLOBALS->alt_hier_delimeter)
-			{
-			strcpy(str, buf);
-			}
-			else
-			{
-			strcpy_vcdalt(str, buf, GLOBALS->alt_hier_delimeter);
-			}
-                s=&sym_block[i];
-                symadd_name_exists_sym_exists(s,str,0);
-		if((prevsym)&&(i>0)&&(!strcmp(f_name[(i)&F_NAME_MODULUS], f_name[(i-1)&F_NAME_MODULUS]))&&(!strchr(f_name[(i)&F_NAME_MODULUS], '\\')))	/* allow chaining for search functions.. */
-			{
-			prevsym->vec_root = prevsymroot;
-			prevsym->vec_chain = s;
-			s->vec_root = prevsymroot;
-			prevsym = s;
-			}
-			else
-			{
-			prevsymroot = prevsym = s;
-			}
-		}
 		else
 		{
-		str=malloc_2(strlen(f_name[(i)&F_NAME_MODULUS])+1);
-		if(!GLOBALS->alt_hier_delimeter)
+                int gatecmp = (f->len==1) && (!(f->flags&(LXT2_RD_SYM_F_INTEGER|LXT2_RD_SYM_F_DOUBLE|LXT2_RD_SYM_F_STRING))) && (node_block[i].msi!=-1) && (node_block[i].lsi!=-1);
+                int revcmp = gatecmp && (i) && (!strcmp(f_name[(i)&F_NAME_MODULUS], f_name[(i-1)&F_NAME_MODULUS]));
+		
+		if(gatecmp)
 			{
-			strcpy(str, f_name[(i)&F_NAME_MODULUS]);
+			int len = sprintf(buf, "%s[%d]", f_name[(i)&F_NAME_MODULUS],node_block[i].msi);
+			str=malloc_2(len+1);
+			if(!GLOBALS->alt_hier_delimeter)
+				{
+				strcpy(str, buf);
+				}
+				else
+				{
+				strcpy_vcdalt(str, buf, GLOBALS->alt_hier_delimeter);
+				}
+	                s=&sym_block[i];
+	                symadd_name_exists_sym_exists(s,str,0);
+			if((prevsym)&&(revcmp)&&(!strchr(f_name[(i)&F_NAME_MODULUS], '\\')))	/* allow chaining for search functions.. */
+				{
+				prevsym->vec_root = prevsymroot;
+				prevsym->vec_chain = s;
+				s->vec_root = prevsymroot;
+				prevsym = s;
+				}
+				else
+				{
+				prevsymroot = prevsym = s;
+				}
 			}
 			else
 			{
-			strcpy_vcdalt(str, f_name[(i)&F_NAME_MODULUS], GLOBALS->alt_hier_delimeter);
-			}
-                s=&sym_block[i];
-                symadd_name_exists_sym_exists(s,str,0);
-		prevsymroot = prevsym = NULL;
-
-		if(f->flags&LXT2_RD_SYM_F_INTEGER)
-			{
-			GLOBALS->mvlfacs_lx2_c_1[i].msb=31;
-			GLOBALS->mvlfacs_lx2_c_1[i].lsb=0;
-			GLOBALS->mvlfacs_lx2_c_1[i].len=32;
+			str=malloc_2(strlen(f_name[(i)&F_NAME_MODULUS])+1);
+			if(!GLOBALS->alt_hier_delimeter)
+				{
+				strcpy(str, f_name[(i)&F_NAME_MODULUS]);
+				}
+				else
+				{
+				strcpy_vcdalt(str, f_name[(i)&F_NAME_MODULUS], GLOBALS->alt_hier_delimeter);
+				}
+	                s=&sym_block[i];
+	                symadd_name_exists_sym_exists(s,str,0);
+			prevsymroot = prevsym = NULL;
+	
+			if(f->flags&LXT2_RD_SYM_F_INTEGER)
+				{
+				node_block[i].msi=31;
+				node_block[i].lsi=0;
+				GLOBALS->mvlfacs_lx2_c_1[i].len=32;
+				}
 			}
 		}
 		
@@ -239,8 +209,6 @@ for(i=0;i<GLOBALS->numfacs;i++)
 
 	if((f->len>1)||(f->flags&(LXT2_RD_SYM_F_DOUBLE|LXT2_RD_SYM_F_STRING)))
 		{
-		n->msi = GLOBALS->mvlfacs_lx2_c_1[i].msb;
-		n->lsi = GLOBALS->mvlfacs_lx2_c_1[i].lsb;
 		n->extvals = 1;
 		}
                  
@@ -259,12 +227,10 @@ for(i=0;i<=F_NAME_MODULUS;i++)
 	}
 free_2(f_name); f_name = NULL;
 
-create_hier_array();
-
 /* SPLASH */                            splash_sync(2, 5);
 GLOBALS->facs=(struct symbol **)malloc_2(GLOBALS->numfacs*sizeof(struct symbol *));
 
-if((GLOBALS->fast_tree_sort) && (!GLOBALS->do_hier_compress))
+if(GLOBALS->fast_tree_sort)
         {
         for(i=0;i<GLOBALS->numfacs;i++)
                 {
@@ -409,18 +375,7 @@ if((GLOBALS->fast_tree_sort) && (!GLOBALS->do_hier_compress))
 	for(i=0;i<GLOBALS->numfacs;i++)	
 		{
 		char *nf = GLOBALS->facs[i]->name;
-		int was_packed;
-		char *recon = hier_decompress_flagged(nf, &was_packed);
-                
-		if(was_packed)   
-		        {
-		        build_tree_from_name(recon, i);
-		        free_2(recon);
-		        }
-		        else
-		        {
-		        build_tree_from_name(nf, i);
-		        }
+	        build_tree_from_name(nf, i);
 		}
 /* SPLASH */                            splash_sync(5, 5);
 	if(GLOBALS->escaped_names_found_vcd_c_1)
@@ -444,12 +399,6 @@ if((GLOBALS->fast_tree_sort) && (!GLOBALS->do_hier_compress))
 	        }
 	}
 
-if(GLOBALS->prev_hier_uncompressed_name) 
-	{
-	free_2(GLOBALS->prev_hier_uncompressed_name);
-	GLOBALS->prev_hier_uncompressed_name = NULL; 
-	}
-
 GLOBALS->min_time = GLOBALS->first_cycle_lx2_c_1; GLOBALS->max_time=GLOBALS->last_cycle_lx2_c_1;
 GLOBALS->is_lx2 = LXT2_IS_LXT2;
 
@@ -529,9 +478,13 @@ if(!(f->flags&(LXT2_RD_SYM_F_DOUBLE|LXT2_RD_SYM_F_STRING)))
 	}
 else if(f->flags&LXT2_RD_SYM_F_DOUBLE)
 	{
+#ifdef WAVE_HAS_H_DOUBLE
+	sscanf(*value, "%lg", &htemp->v.h_double);
+#else
 	double *d = malloc_2(sizeof(double));
 	sscanf(*value, "%lg", d);
 	htemp->v.h_vector = (char *)d;
+#endif
 	htemp->flags = HIST_REAL;
 	}
 else	/* string */
@@ -618,7 +571,7 @@ fprintf(stderr, "Import: %s\n", np->nname);
 /* new stuff */
 len = np->mv.mvlfac->len;
 
-if(f->array_height <= 1) /* sorry, arrays not supported, but lx2 doesn't support them yet either */
+if(f->node_alias <= 1) /* sorry, arrays not supported, but lx2 doesn't support them yet either */
 	{
 	lxt2_rd_set_fac_process_mask(GLOBALS->lx2_lx2_c_1, txidx);
 	lxt2_rd_iter_blocks(GLOBALS->lx2_lx2_c_1, lx2_callback, NULL);
@@ -737,7 +690,7 @@ if(np->mv.mvlfac->flags&LXT2_RD_SYM_F_ALIAS)
 	if(!(np->mv.mvlfac)) return;	/* already imported */
 	}
 
-if(np->mv.mvlfac->array_height <= 1) /* sorry, arrays not supported, but lx2 doesn't support them yet either */
+if(np->mv.mvlfac->node_alias <= 1) /* sorry, arrays not supported, but lx2 doesn't support them yet either */
 	{
 	lxt2_rd_set_fac_process_mask(GLOBALS->lx2_lx2_c_1, txidx);
 	GLOBALS->lx2_table_lx2_c_1[txidx].np = np;
@@ -869,8 +822,20 @@ for(txidx=0;txidx<GLOBALS->numfacs;txidx++)
 }
 
 /*
- * $Id: lx2.c,v 1.18 2010/09/15 18:35:42 gtkwave Exp $
+ * $Id: lx2.c,v 1.22 2011/01/22 01:29:24 gtkwave Exp $
  * $Log: lx2.c,v $
+ * Revision 1.22  2011/01/22 01:29:24  gtkwave
+ * sourcecode cleanup / warnings fixes
+ *
+ * Revision 1.21  2011/01/21 15:49:52  gtkwave
+ * simplify strand coalesce routine and make same as FST's
+ *
+ * Revision 1.20  2011/01/13 17:20:39  gtkwave
+ * rewrote hierarchy / facility packing code
+ *
+ * Revision 1.19  2011/01/07 20:17:10  gtkwave
+ * remove redundant fields from struct fac
+ *
  * Revision 1.18  2010/09/15 18:35:42  gtkwave
  * added F_NAME_MODULUS to reduce temp memory usage
  *
